@@ -1,7 +1,7 @@
 package Catmandu::EuropePMC;
 
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 1;
 __END__
@@ -18,7 +18,7 @@ Catmandu::EuropePMC - A bundle of Catmandu modules for working with data from Eu
 
 <p>
 <a href="https://travis-ci.org/LibreCat/Catmandu-EuropePMC"><img src="https://travis-ci.org/LibreCat/Catmandu-EuropePMC.svg?branch=master" alt="build status" /></a>
-<a href="https://coveralls.io/repos/LibreCat/Catmandu-EuropePMC"><img src="https://coveralls.io/repos/LibreCat/Catmandu-EuropePMC/badge.png?branch=master" alt="coverage status" /></a>
+<a href="https://coveralls.io/r/LibreCat/Catmandu-EuropePMC"><img src="https://coveralls.io/repos/LibreCat/Catmandu-EuropePMC/badge.png?branch=master" alt="coverage status" /></a>
 <a href="http://cpants.cpanauthors.org/dist/Catmandu-EuropePMC"><img src="http://cpants.cpanauthors.org/dist/Catmandu-EuropePMC.png" alt="kwalitee score" /></a>
 </p>
 
